Function lowertest_derive::get_field_name_type [−][src]
Gets the name and the type of a field of an enum variant or struct.
The result has three parts:
- The name of the field. If the field is unnamed, this is empty.
- The type of the field as a string.
- The type of the field as syn::Type.
Returns None if the field has the attribute #[mzreflect(ignore)].